testing

package
v0.0.0-...-7630055 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 16, 2016 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func WatchForFinishedTestRuns

func WatchForFinishedTestRuns(cfg config.Config) error

WatchForFinishedTestRuns simply watches the local cache for any test runs that have test data. It will periodically look at the table and send any present test data back to the server as a response. When the server has successfully received this data, it will send a task back to this specific agent to delete this row from the cache.

Types

This section is empty.

Jump to