Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CalculateGroups ¶
CalculateGroups is a function designed to ingest a list of group objects, a collection of agents, and return a map that contains the resulting group for each agent UUID.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.