Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func WatchForFinishedTestRuns ¶
WatchForFinishedTestRuns simply watches the local cache for any test runs that have test data. It will periodically look at the table and send any present test data back to the server as a response. When the server has successfully received this data, it will send a task back to this specific agent to delete this row from the cache.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.